mimedb

package module
v0.0.0-...-e8af1d6 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 7, 2018 License: MIT Imports: 1 Imported by: 1

README

MIME DB

This Go package uses generators to convert this database into additions to the stdlib mime package.

Since all the work is done at compile time, the MIME types end up embedded in the binary, loading them on startup is fast, and you still get sensible results when /etc/mime.types is unavailable on your platform!

This work is somewhat inspired by mime-ext-go, which lacks the automatic generation (and so easy update) to be found in this package.

The version of the mime-db package used is tracked in the VERSION file, and updates will be given a corresponding tag.

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func LoadTypes

func LoadTypes() error

Types

This section is empty.

Directories

Path Synopsis
cmd
generate command

Jump to